
##### begin loading data
source("utils_mer.txt")
source("utils_chart_maker.txt")

# lexicon
lex = read.csv("portuguese_lexicon.csv")
lex$finalV = factor(lex$finalV, levels=c("a","ɛ","ɔ","e","o","i","u"))
lex$stressV = factor(lex$stressV, levels=c("a","ɛ","ɔ","e","o","i","u"))
lex$shape = factor(lex$shape, levels=c("mono", "iamb", "trochee"))
#lex$lax = ifelse(lex$stressV %in% c("i","u"), 0, ifelse(lex$stressV %in% c("e","o"), -1, 1))




# experiment 4: judgments on 1-7 scale, natural stimuli
exp4 = read.csv("portuguese_experiment_scale.csv")
exp4$time = as.POSIXct(exp4$time)
exp4$shape = factor(exp4$shape, levels=c("mono", "troc", "iamb"))
exp4$stressedV = factor(exp4$stressedV, levels=c("a","ɛ","ɔ","e","o","i","u"))
exp4$finalV = factor(exp4$finalV, levels=c("a","ɛ","ɔ","e","o","i","u"))
exp4$lax = ifelse(exp4$stressedV %in% c("i","u"), 0, ifelse(exp4$stressedV %in% c("e","o"), -1, 1))
exp4$FVlax = ifelse(exp4$finalV %in% c("i","u"), 0, ifelse(exp4$finalV %in% c("e","o"), -1, 1))
exp4$FVlax.bin = exp4$finalV %in% c("a","ɛ","ɔ") 

exp4$back = scale(exp4$stressedV %in% c("o","ɔ","u","a")) 
exp4$tback = ifelse(exp4$shape!="troc", 0, ifelse(exp4$finalV=="o",1, -1))  
exp4$high = scale(exp4$stressedV %in% c("i","u"))
exp4$low = ifelse(exp4$stressedV %in% c("i","u","e","o"), 0, ifelse(exp4$stressedV %in% c("a"), 2/3, -1/3))
exp4$c.mono   = ifelse(exp4$shape=="mono",-1,ifelse(exp4$shape=="iamb",.5,.5)) 
exp4$c.stress = ifelse(exp4$shape=="mono",0 ,ifelse(exp4$shape=="iamb",1,-1)) 
exp4$c.nabers.sg = scale(exp4$nabers.sg+1);
exp4$l.nabers.sg = scale(log(exp4$nabers.sg+1));
exp4$c.nabers.pl1 = scale(exp4$nabers.pl1+1);
exp4$l.nabers.pl1 = scale(log(exp4$nabers.pl1+1));
exp4$c.nabers.pl2 = scale(exp4$nabers.pl2+1);
exp4$l.nabers.pl2 = scale(log(exp4$nabers.pl2+1));

exp4$c.stem = scale(exp4$sg_stem)


exp4 = subset(exp4, type=="target")
meta4 = read.csv("portuguese_meta_scale.csv")

# experiment 5: binary judgments, natural stimuli
exp5 = read.csv("portuguese_experiment_binary.csv")
exp5$time = as.POSIXct(exp5$time)
exp5$shape = factor(exp5$shape, levels=c("mono", "troc", "iamb"))
exp5$stressedV = factor(exp5$stressedV, levels=c("a","ɛ","ɔ","e","o","i","u"))
exp5$finalV = factor(exp5$finalV, levels=c("a","ɛ","ɔ","e","o","i","u"))
exp5$lax = ifelse(exp5$stressedV %in% c("i","u"), 0, ifelse(exp5$stressedV %in% c("e","o"), -1, 1))
exp5$FVlax = ifelse(exp5$finalV %in% c("i","u"), 0, ifelse(exp5$finalV %in% c("e","o"), -1, 1))
exp5$FVlax.bin = exp5$finalV %in% c("a","ɛ","ɔ") 

exp5 = subset(exp5, type=="target")
exp5$c.base = scale(exp5$response1, scale=4)
exp5$c.mono = ifelse(exp5$shape=="mono",-1,ifelse(exp5$shape=="troc",1,0)) 
exp5$r.mono = residuals(lm(c.mono ~ c.base, data=exp5))
exp5$c.stress = ifelse(exp5$shape=="mono",-.5,ifelse(exp5$shape=="troc",-.5,1)) 
exp5$r.stress = residuals(lm(c.stress ~ c.base, data=exp5))
exp5$r.lax = residuals(lm(lax ~ c.base, data=exp5))
exp5$c.order = scale(exp5$order)
exp5$back = scale(exp5$stressedV %in% c("o","ɔ","u","a")) 
exp5$high = scale(exp5$stressedV %in% c("i","u"))
exp5$low = ifelse(exp5$stressedV %in% c("i","u","e","o"), 0, ifelse(exp5$stressedV %in% c("a"), 2/3, -1/3))
exp5$tback = ifelse(exp5$shape!="troc", 0, ifelse(exp5$finalV=="o",1, -1))  
exp5$c.stress = ifelse(exp5$shape=="mono",0,ifelse(exp5$shape=="iamb",1,-1)) 
exp5$r.stress = residuals(lm(c.stress ~ c.base, data=exp5))
exp5$c.mono = ifelse(exp5$shape=="mono",.5,ifelse(exp5$shape=="iamb",-.5,-.5)) 
exp5$r.mono = residuals(lm(c.mono ~ c.base, data=exp5))
exp5$c.nabers.sg = scale(exp5$nabers.sg+1);
exp5$l.nabers.sg = scale(log(exp5$nabers.sg+1));
exp5$c.nabers.pl1 = scale(exp5$nabers.pl1+1);
exp5$l.nabers.pl1 = scale(log(exp5$nabers.pl1+1));
exp5$c.nabers.pl2 = scale(exp5$nabers.pl2+1);
exp5$l.nabers.pl2 = scale(log(exp5$nabers.pl2+1));


# size and vowel predictors - lexicon
lex$c.poly   = ifelse(lex$shape=="mono",-.5,ifelse(lex$shape=="iamb",.5,.5)) 
lex$c.stress = ifelse(lex$shape=="mono",0 ,ifelse(lex$shape=="iamb",-.5,.5)) 
lex$FVback = (lex$finalV %in% c("a","o","ɔ","u")) -.5
lex$FVhigh = (lex$finalV %in% c("i","u")) - .5
lex$FVlow  = (lex$finalV %in% c("a")) - .5
lex$FVlax = (! lex$finalV %in% c("i","u","e","o")) - 0.7312661

# size and vowel predictors - exp4
exp4$c.poly   = ifelse(exp4$shape=="mono",-.5,ifelse(exp4$shape=="iamb",.5,.5)) 
exp4$c.stress = ifelse(exp4$shape=="mono",0 ,ifelse(exp4$shape=="iamb",-.5,.5)) 
exp4$FVback = (exp4$finalV %in% c("a","o","ɔ","u")) -.5
exp4$FVhigh = (exp4$finalV %in% c("i","u")) - .5
exp4$FVlow  = (exp4$finalV %in% c("a")) - .5
exp4$FVlax = (! exp4$finalV %in% c("i","u","e","o")) - 0.2813996

# size and vowel predictors - exp5
exp5$c.poly   = ifelse(exp5$shape=="mono",-.5,ifelse(exp5$shape=="iamb",.5,.5)) 
exp5$c.stress = ifelse(exp5$shape=="mono",0 ,ifelse(exp5$shape=="iamb",-.5,.5)) 
exp5$FVback = (exp5$finalV %in% c("a","o","ɔ","u")) -.5
exp5$FVhigh = (exp5$finalV %in% c("i","u")) - .5
exp5$FVlow  = (exp5$finalV %in% c("a")) - .5
exp5$FVlax = (! exp5$finalV %in% c("i","u","e","o")) - 0.3009259

meta5 = read.csv("portuguese_meta_binary.csv")

exp4$sg_prop = exp4$sg_suff/(exp4$sg_suff + exp4$sg_stem)
exp4$pl1_prop = exp4$pl1_suff/(exp4$pl1_suff + exp4$pl1_stem)
exp4$pl2_prop = exp4$pl2_suff/(exp4$pl2_suff + exp4$pl2_stem)
exp5$sg_prop = exp5$sg_suff/(exp5$sg_suff + exp5$sg_stem)
exp5$pl1_prop = exp5$pl1_suff/(exp5$pl1_suff + exp5$pl1_stem)
exp5$pl2_prop = exp5$pl2_suff/(exp5$pl2_suff + exp5$pl2_stem)

# inverse monosyllabicity
lex$c.poly = -1 * lex$c.poly
exp4$c.poly = -1 * exp4$c.poly
exp5$c.poly = -1 * exp5$c.poly



##### done loading data







# lexicon descriptive stats
xtabs(~unfaith, data=lex)
aggregate(unfaith ~ shape, lex, mean)
aggregate(unfaith ~ I(shape=="mono"), lex,  mean)



#### lexicon plot
quartz.fnc(cwidth=13,cheight=5,cname="r.portuguese.lex2.pdf")
c=gray(seq(.6,1,length.out=3))
par(family=myfont,ps=pointsize,mar=c(5,6,1.5,14),mfrow=c(1,1),oma=c(0,0,0,0))
lex$shape = factor(lex$shape, levels=c("mono", "trochee", "iamb"))
x = xtabs( ~ I(1-faith) + I(FVlax>0) + shape , data=lex);x = cbind(x[,,1], x[,,2], x[,,3])
x = x[,-4] # no lax trochees
y = barplot(prop.table(x,2), width=colSums(x), yaxt="n", xaxt="n", col=c, space=c(0,.03,.3,.3,.03));
axis(1, at=y, tick=F, c("tense", "lax","tense", "tense","lax"), cex.axis=1.5, las=2, line=-.5)
axis(1, at=c(mean(y[1:2]),y[3],mean(y[4:5])), c("mono", "trochee", "iamb"), cex.axis=2, line=2.9, tick=F)
axis(2, at=seq(0,1,.2), paste(seq(0,1,.2)*100,"%",sep=""), cex.axis=1.5, las=1);
title(ylab="proportion of unfaithful plurals", cex.lab=1.5, xpd=T, line=4.5)
legend(x=460, y=1, c("faithful","variable","unfaithful"), fill=rev(c), cex=2, xpd=T)
rm(x,y,c)
if (chartmode=="pdf") {dev.off()}




library(arm)
glm1 = glm(unfaith>=.5 ~ c.poly + c.stress + FVlax , family="binomial", data=lex);summary(glm1);kappa(glm1)
write.table(round(summary(glm1)$coef,2), sep="\t&\t", eol="\\\\\n", quote=F)

glm2 = glm(unfaith>=.5 ~ c.poly + c.stress + FVlax + c.poly:FVlax , family="binomial", data=lex);summary(glm2);kappa(glm2) ### bad model
anova(glm1, glm2, test="Chisq")









######  experiment charts

quartz.fnc(cwidth=8,cheight=5,cname="r.portuguse.scalar2.pdf")
p = make.matrix(exp4, response1-1 ~ I(FVlax>0) + shape)
plot.portuguese(p,1,7,"preference for alternating plural")

quartz.fnc(cwidth=6,cheight=5,cname="r.portuguse.binary.base2.pdf")
p = make.matrix(exp5, response1-1 ~ I(FVlax>0) + shape)
plot.portuguese(p,1,5,"mean rating of singular")

quartz.fnc(cwidth=6,cheight=5,cname="r.portuguse.binary.jplural2.pdf")
p = make.matrix(exp5, pl.j ~ I(FVlax>0) + shape)
plot.portuguese(p,0,1,"acceptability of alternating plural")




# experiments descriptive stats
aggregate(response1 ~  shape           , exp4, mean)
aggregate(response1 ~ I(lax==1)        , exp4, mean)
aggregate(response1 ~ I(lax==1) + shape, exp4, mean)

aggregate(response1 ~  shape           , exp5, mean)
aggregate(response1 ~ I(lax==1)        , exp5, mean)
aggregate(response1 ~ I(lax==1) + shape, exp5, mean)

aggregate(pl.j ~  shape           , exp5, mean)
aggregate(pl.j ~ I(lax==1)        , exp5, mean)
aggregate(pl.j ~ I(lax==1) + shape, exp5, mean)



# exp 4 regression
library(lme4.0) # 
Sys.time(); lmer.exp4f = 
  lmer(response1 ~ c.poly + c.stress + FVlax*c.poly + 
         (1 + c.poly + c.stress + FVlax*c.poly |userCode) + 
         (1  |item), 
         data=exp4); Sys.time();  system("afplay ~/dimdom.wav")
lmer.exp4f
max(vif.mer(lmer.exp4f))
kappa.mer(lmer.exp4f)
tabl = cbind(round(summary(lmer.exp4f)@coefs,2), round(2*(1-pnorm(abs(summary(lmer.exp4f)@coefs[,3]))),4))
write.table(tabl, quote=F, sep="  &  ", eol="\\\\\n")
rm(tabl)



# exp 5 regression
Sys.time(); lmer.exp5f = 
  lmer(pl.j ~ c.base + c.poly + c.stress + FVlax*c.poly + 
         (1 + c.base + c.poly + c.stress + FVlax*c.poly | userCode) + 
         (1 + c.base | item), 
       data=exp5, family="binomial"); Sys.time(); system("afplay ~/dimdom.wav")
sort(sapply(ranef(lmer.exp5f)$item, sd))
sort(sapply(ranef(lmer.exp5f)$userCode, sd))
lmer.exp5f
write.table(round(summary(lmer.exp5f)@coefs,2), quote=F, sep="  &  ", eol="\\\\\n")
max(vif.mer(lmer.exp5f))
kappa.mer(lmer.exp5f)








##### MAXENT VS. LEXICON
p = data.frame(shape=c("mono","mono","iamb","iamb","troc"), FVlax.bin=c(F,T,F,T,F))
p$maxent = c(.074, .414,  .569, .922,  .957)
exp4 = merge(exp4, p)
exp5 = merge(exp5, p)

p = aggregate(response1 ~ shape + FVlax.bin + item, exp4, mean)
p = merge(p, aggregate(pl.j ~ shape + FVlax.bin + item , exp5, mean))
p = merge(p, aggregate(maxent ~ shape + FVlax.bin + item , exp5, mean))
colnames(p)[4:5] = c("exp4","exp5")

summary(replicate(1000, cor.test(jitter(p$exp4), jitter(p$maxent), method="s")$estimate))
summary(replicate(1000, cor.test(jitter(p$exp5), jitter(p$maxent), method="s")$estimate))
summary(replicate(1000, cor.test(jitter(p$exp4), jitter(p$maxent), method="s")$p.value))
summary(replicate(1000, cor.test(jitter(p$exp5), jitter(p$maxent), method="s")$p.value))



quartz.fnc(cwidth=12,cheight=5,cname="r.bp.lex.vs.exp.byitem.pdf")
par(family=myfont,ps=pointsize,mar=c(5,5,2,2),mfrow=c(1,2))
plot(exp4 ~ jitter(maxent, factor=2), p, cex=1, ylim=c(1,7.0), xlim=c(0,1), xaxt="n", main="Experiment 4 (n=181)", frame.plot=F, cex.axis=1.4, cex.lab=1.8, cex.main=2, xlab="MaxEnt model predictions", ylab="mean participant response")
axis(1, seq(0,1,.2), paste(seq(0,1,.2)*100, "%",sep=""), cex.axis=1.4)
abline(lm(exp4 ~ maxent, p), col="gray50")
text(.9, 1.2, "ρ = .41", cex=2, xpd=T)
#
plot(exp5 ~ jitter(maxent, factor=2), p, cex=1, xaxt="n", yaxt="n", main="Experiment 5 (n=72)", frame.plot=F, ylim=c(0,1.05), xlim=c(0,1), cex.axis=1.4, cex.lab=1.8, cex.main=2, xlab="MaxEnt model predictions", ylab="mean participant response")
axis(1, seq(0,1,.2), paste(seq(0,1,.2)*100, "%",sep=""), cex.axis=1.4)
axis(2, seq(0,1,.2), paste(seq(0,1,.2)*100, "%",sep=""), cex.axis=1.4)
abline(lm(exp5 ~ maxent, p), col="gray50")
text(.9, 0.04, "ρ = .41", cex=2, xpd=T)
if (chartmode=="pdf") {dev.off()}







###  NEIGHBORS IN MONOS AND POLYS SEPARATELY
# exp 4
x = unique(exp4[,c("item", "shape", "l.nabers.sg", "l.nabers.pl1", "l.nabers.pl2")]);
x = merge(x, aggregate(response1 ~ item, exp4, mean))

with(x, cor.test(response1, l.nabers.sg))
with(x, cor.test(response1, l.nabers.pl1))
with(x, cor.test(response1, l.nabers.pl2))

with(subset(x, shape=="mono"), cor.test(response1, l.nabers.sg))
with(subset(x, shape=="mono"), cor.test(response1, l.nabers.pl1))
with(subset(x, shape=="mono"), cor.test(response1, l.nabers.pl2))

with(subset(x, shape!="mono"), cor.test(response1, l.nabers.sg))
with(subset(x, shape!="mono"), cor.test(response1, l.nabers.pl1))
with(subset(x, shape!="mono"), cor.test(response1, l.nabers.pl2))

# exp 5
x = unique(exp5[,c("item", "shape", "l.nabers.sg", "l.nabers.pl1", "l.nabers.pl2")]);
x = merge(x, aggregate(pl.j ~ item, exp5, mean))

with(x, cor.test(pl.j, l.nabers.sg))
with(x, cor.test(pl.j, l.nabers.pl1))
with(x, cor.test(pl.j, l.nabers.pl2))

with(subset(x, shape=="mono"), cor.test(pl.j, l.nabers.sg))
with(subset(x, shape=="mono"), cor.test(pl.j, l.nabers.pl1))
with(subset(x, shape=="mono"), cor.test(pl.j, l.nabers.pl2))

with(subset(x, shape!="mono"), cor.test(pl.j, l.nabers.sg))
with(subset(x, shape!="mono"), cor.test(pl.j, l.nabers.pl1))
with(subset(x, shape!="mono"), cor.test(pl.j, l.nabers.pl2))









